==> react-card-image-cover-1.5.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";

/* eslint-disable react/prop-types */
import AtomPanel from '@s-ui/react-atom-panel';
import React from 'react';
import PropTypes from 'prop-types';
import SuiTagChip from '@schibstedspain/sui-tag-chip';

var CardImageCover = function CardImageCover(_ref) {
  var media = _ref.media,
      title = _ref.title,
      text = _ref.text,
      tag = _ref.tag,
      TagChip = _ref.tagChip,
      Link = _ref.linkFactory,
      url = _ref.url;

  var onClick = function onClick() {
    if (url) window.location.href = url;
  };

  var BASE_CLASS = 'sui-CardImageCover';
  var TITLE_CLASS = BASE_CLASS + "-title";
  var LINK_CLASS = BASE_CLASS + "-link";
  var INNER_CLASS = BASE_CLASS + "-inner";
  var TEXT_CLASS = BASE_CLASS + "-text";
  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement(AtomPanel, {
    src: media.src,
    resized: true
  }, React.createElement("div", {
    className: INNER_CLASS,
    onClick: onClick
  }, tag && React.createElement("div", null, React.createElement(TagChip, {
    rel: tag.rel,
    label: tag.text,
    link: tag.url,
    linkFactory: Link,
    className: tag.className
  })), React.createElement("h2", {
    className: TITLE_CLASS
  }, React.createElement(Link, {
    href: url,
    title: title,
    className: LINK_CLASS
  }, title)), React.createElement("p", {
    className: TEXT_CLASS
  }, text))));
};

CardImageCover.displayName = 'CardImageCover';
CardImageCover.defaultProps = {
  tagChip: SuiTagChip,
  linkFactory: function linkFactory(_ref2) {
    var children = _ref2.children,
        rest = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return React.createElement("a", rest, children);
  }
};
export default CardImageCover;

==> react-card-image-cover-1.6.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";

/* eslint-disable react/prop-types */
import AtomPanel from '@s-ui/react-atom-panel';
import React from 'react';
import PropTypes from 'prop-types';
import SuiTagChip from '@s-ui/react-tag-chip';

var CardImageCover = function CardImageCover(_ref) {
  var media = _ref.media,
      title = _ref.title,
      text = _ref.text,
      tag = _ref.tag,
      TagChip = _ref.tagChip,
      Link = _ref.linkFactory,
      url = _ref.url;

  var onClick = function onClick() {
    if (url) window.location.href = url;
  };

  var BASE_CLASS = 'sui-CardImageCover';
  var TITLE_CLASS = BASE_CLASS + "-title";
  var LINK_CLASS = BASE_CLASS + "-link";
  var INNER_CLASS = BASE_CLASS + "-inner";
  var TEXT_CLASS = BASE_CLASS + "-text";
  return React.createElement("div", {
    className: BASE_CLASS
  }, React.createElement(AtomPanel, {
    src: media.src,
    resized: true
  }, React.createElement("div", {
    className: INNER_CLASS,
    onClick: onClick
  }, tag && React.createElement("div", null, React.createElement(TagChip, {
    rel: tag.rel,
    label: tag.text,
    link: tag.url,
    linkFactory: Link,
    className: tag.className
  })), React.createElement("h2", {
    className: TITLE_CLASS
  }, React.createElement(Link, {
    href: url,
    title: title,
    className: LINK_CLASS
  }, title)), React.createElement("p", {
    className: TEXT_CLASS
  }, text))));
};

CardImageCover.displayName = 'CardImageCover';
CardImageCover.defaultProps = {
  tagChip: SuiTagChip,
  linkFactory: function linkFactory(_ref2) {
    var children = _ref2.children,
        rest = _objectWithoutPropertiesLoose(_ref2, ["children"]);

    return React.createElement("a", rest, children);
  }
};
export default CardImageCover;
